"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.startHttpServer = void 0;
const http_1 = require("http");
const url_1 = require("url");
const prom_client_1 = require("prom-client");
function startHttpServer(port, service) {
    console.log("Starting HTTP server on port " + port);
    const server = (0, http_1.createServer)(async (req, res) => {
        const sendResponse = async (data, statusCode, headers) => {
            res.writeHead(statusCode, headers);
            res.end(data);
        };
        if (req.method === "GET" && req.url) {
            const parts = (0, url_1.parse)(req.url);
            if (parts.pathname === "/metrics") {
                sendResponse(await prom_client_1.register.metrics(), 200, {
                    "Content-Type": "text/plain",
                });
                return;
            }
            if (parts.pathname === "/status") {
                if (service.mqttConnected) {
                    sendResponse("OK", 200, {
                        "Content-Type": "text/plain",
                    });
                }
                else {
                    sendResponse("Not OK", 500, {
                        "Content-Type": "text/plain",
                    });
                }
                return;
            }
        }
        sendResponse("Not found", 404, { "Content-Type": "text/plain" });
    });
    server.listen(port, () => {
        console.log("Server now listening on port " + port);
    });
    server.on("error", (err) => {
        console.error("HTTP server error " + err);
    });
}
exports.startHttpServer = startHttpServer;
//# sourceMappingURL=http.js.map