import { MqttConfig } from "./config";
import { Logger } from "./logging";
export declare type QoS = 0 | 1 | 2;
export declare type ServiceEvent = "message";
export interface PublishOptions {
    /**
     * the QoS
     */
    qos: QoS;
    /**
     * the retain flag
     */
    retain?: boolean;
}
export interface Service<ServiceConfig> {
    /** The service config loaded from file, or passed into create. */
    readonly config: ServiceConfig;
    /** MQTT topic prefix in use for publishing. */
    readonly prefix: string;
    /** True if mqtt is connected */
    readonly mqttConnected: boolean;
    /** Subscribe to events on this topic. */
    subscribe(key: string): void;
    send(key: string, data: any, options?: PublishOptions): void;
    end(): void;
    on(event: ServiceEvent, listener: (topic: string, data: any) => void): void;
    removeListener(event: ServiceEvent, listener: (topic: string, data: any) => void): void;
    removeAllListeners(event: ServiceEvent): void;
}
export declare function createService<ServiceConfig>(mqttConfig: Required<MqttConfig>, serviceConfig: ServiceConfig, logger: Logger): Service<ServiceConfig>;
